pub struct OverlayDirectoryObject {
overlay_fs: Arc<OverlayFS>,
path: String,
position: RwLock<u64>,
}Expand description
File object for OverlayFS directory operations
OverlayDirectoryObject handles reading directory entries from overlayfs, merging entries from upper and lower layers while respecting whiteout files.
Fields
overlay_fs: Arc<OverlayFS>path: Stringposition: RwLock<u64>Implementations
Sourceimpl OverlayDirectoryObject
impl OverlayDirectoryObject
pub fn new(overlay_fs: Arc<OverlayFS>, path: String) -> Self
Sourcefn collect_directory_entries(
&self,
) -> Result<Vec<DirectoryEntryInternal>, FileSystemError>
fn collect_directory_entries( &self, ) -> Result<Vec<DirectoryEntryInternal>, FileSystemError>
Collect all directory entries from all layers, handling whiteouts and merging
Sourcefn try_fs_from_mount(
mount: &Arc<MountPoint>,
) -> Result<Arc<dyn FileSystemOperations>, FileSystemError>
fn try_fs_from_mount( mount: &Arc<MountPoint>, ) -> Result<Arc<dyn FileSystemOperations>, FileSystemError>
Safe version of fs_from_mount that returns Result instead of panicking